:mod:`cybox.objects.disk_partition_object` module
=================================================

.. automodule:: cybox.objects.disk_partition_object
    :members:
    :undoc-members:
    :show-inheritance:
